==> ds-bootstrap-0.3.0-alpha.1.tgz: package/esm/Widgets/OptionsBoolean/OptionsBoolean.js <==
import React from 'react';
import { TransTitle } from '@ui-schema/ui-schema';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';

const BoolRenderer = ({
  ownKey,
  showValidity,
  required,
  errors,
  value,
  storeKeys,
  onChange,
  schema
}) => {
  let classForm = ['custom-control', 'custom-switch'];
  let classLabel = ['custom-control-label', 'text-light'];
  let classFormControl = ['custom-control-input'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  let currentChecked = !!value;
  return /*#__PURE__*/React.createElement("div", {
    className: classForm.join(' ')
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    className: classFormControl.join(' '),
    id: ownKey,
    checked: currentChecked,
    required: required,
    onChange: () => onChange(storeKeys, ['value'], {
      type: 'update',
      update: ({
        value: storeValue
      }) => ({
        value: !storeValue
      }),
      schema,
      required
    })
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel.join(' '),
    htmlFor: ownKey
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), required ? ' *' : ''), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { BoolRenderer };

==> ds-bootstrap-0.4.0-alpha.1.tgz: package/esm/Widgets/OptionsBoolean/OptionsBoolean.js <==
import React from 'react';
import { useUID } from 'react-uid';
import { TransTitle } from '@ui-schema/ui-schema';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';

const BoolRenderer = ({
  showValidity,
  required,
  errors,
  value,
  storeKeys,
  onChange,
  schema
}) => {
  const id = useUID();
  let classForm = ['custom-control', 'custom-switch'];
  let classLabel = ['custom-control-label', 'text-light'];
  let classFormControl = ['custom-control-input'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  let currentChecked = !!value;
  return /*#__PURE__*/React.createElement("div", {
    className: classForm.join(' ')
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    className: classFormControl.join(' '),
    id: 'uis-' + id,
    checked: currentChecked,
    required: required,
    onChange: () => onChange({
      storeKeys,
      scopes: ['value'],
      type: 'update',
      updater: ({
        value: storeValue
      }) => ({
        value: !storeValue
      }),
      schema,
      required
    })
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel.join(' '),
    htmlFor: 'uis-' + id
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys
  }), required ? ' *' : ''), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { BoolRenderer };
